@@ -498,7 +498,7 @@ cdrecord_stdout_line (NautilusBurnProcess   *process,
 	} else if (g_str_has_prefix (line, "Fixating time:")) {
 		g_signal_emit (recorder,
 			       nautilus_burn_recorder_table_signals [PROGRESS_CHANGED], 0,
-			       1.0, -1);
+			       1.0, (long)-1);
 		process->result = NAUTILUS_BURN_RECORDER_RESULT_FINISHED;
 	} else if (g_str_has_prefix (line, "Last chance to quit, ")) {
 		process->dangerous = TRUE;
@@ -581,7 +581,7 @@ dvdrw_format_stderr_line (NautilusBurnProcess   *process,
 
 			g_signal_emit (recorder,
 				       nautilus_burn_recorder_table_signals [PROGRESS_CHANGED], 0,
-				       percent, -1);
+				       percent, (long)-1);
 		}
 
 	} else {
@@ -731,7 +731,6 @@ nautilus_burn_recorder_wait_for_insertion (NautilusBurnRecorder *recorder,
 	gboolean              is_rewritable;
 	gboolean              can_write;
 	gboolean              is_blank;
-	gboolean              is_mounted;
 	gboolean              has_data;
 	gboolean              has_audio;
 
@@ -741,7 +740,11 @@ nautilus_burn_recorder_wait_for_insertion (NautilusBurnRecorder *recorder,
 
 	/* if drive is mounted then unmount before checking anything */
 	if (nautilus_burn_drive_is_mounted (drive)) {
-		nautilus_burn_drive_unmount (drive);
+		gboolean res;
+		res = nautilus_burn_drive_unmount (drive);
+		if (! res) {
+			g_warning ("Couldn't unmount volume in drive: %s", drive->device);
+		}
 	}
 
 	media_size = nautilus_burn_drive_get_media_size (drive);
@@ -1182,7 +1185,7 @@ nautilus_burn_recorder_run_process (NautilusBurnRecorder       *recorder,
 		       media_type);
 	g_signal_emit (G_OBJECT (recorder),
 		       nautilus_burn_recorder_table_signals [PROGRESS_CHANGED], 0,
-		       0.0, -1);
+		       0.0, (long)-1);
 	g_signal_emit (G_OBJECT (recorder),
 		       nautilus_burn_recorder_table_signals [ANIMATION_CHANGED], 0,
 		       TRUE);
@@ -1387,7 +1390,7 @@ cdrdao_stderr_line (NautilusBurnProcess   *process,
 			       NAUTILUS_BURN_RECORDER_MEDIA_CD);
 		g_signal_emit (recorder,
 			       nautilus_burn_recorder_table_signals [PROGRESS_CHANGED], 0,
-			       0.0, -1);
+			       0.0, (long)-1);
 
 	}
 
@@ -1396,7 +1399,7 @@ cdrdao_stderr_line (NautilusBurnProcess   *process,
 		process->result = NAUTILUS_BURN_RECORDER_RESULT_FINISHED;
 		g_signal_emit (recorder,
 			       nautilus_burn_recorder_table_signals [PROGRESS_CHANGED], 0,
-			       1.0, -1);
+			       1.0, (long)-1);
 
 	}
 
